scopus.ScopusSearch
===================

.. currentmodule:: scopus

.. autoclass:: ScopusSearch
      
   .. rubric:: Attributes

   .. autosummary::
   
      ~ScopusSearch.EIDS
      ~ScopusSearch.org_summary
